//////////////////////////////////////////////////////////////////////////////
//
// Copyright  2002-2003, Microsoft Corporation.  All rights reserved.
//
// File: Dependencies.js
//
// Description: Utility functions that are associated with the use of
//		external dependencies, currently MSXML and Flash.
//
//////////////////////////////////////////////////////////////////////////////

var g_sXmlParserProgID = "";

//--------------------------------------------------------------------
// Function: GetXmlParserProgID
//
// Purpose:
//	Gets the ProgID of the highest available version of the 
//	Microsoft XML parser.
//
// Parameters: None
//
// Returns: String (i.e. "Msxml2.DOMDocument.4.0")
//
//--------------------------------------------------------------------
function GetXmlParserProgID()
{
	var MAX_MAJOR_PARSER_VERSION = 10;
	var MIN_MAJOR_PARSER_VERSION = 0;
	var MAX_MINOR_PARSER_VERSION = 9;
	var MIN_MINOR_PARSER_VERSION = 0;
	
	var sProgID = g_sXmlParserProgID;
	var bFound = false;

	if (!sProgID)
	{
		// Iterate through possible versions
  		for (var nMajor = MAX_MAJOR_PARSER_VERSION; nMajor >= MIN_MAJOR_PARSER_VERSION; nMajor--)
		{
			for (var nMinor = MAX_MINOR_PARSER_VERSION; nMinor >= MIN_MINOR_PARSER_VERSION; nMinor--)
			{
				// Set up the classname for the version that we're trying to instantiate
				sProgID = "Msxml2.DOMDocument." + nMajor + "." + nMinor;

				try
				{ 
	    				if (new ActiveXObject(sProgID)) 
					{
						bFound = true;
						break;
					}
				}
				catch(e)
				{
				}
			}

			if (bFound)
			{
				// store in a global variable to speedup subsequent calls
				g_sXmlParserProgID = sProgID;
				break;
			}
		}
	}
	
	return sProgID;
}

//--------------------------------------------------------------------
// Function: GetXmlParserVersion
//
// Purpose:
//	Gets the highest available version of the Microsoft XML parser
//
// Parameters: None
//
// Returns: String (i.e. "2.6")
//--------------------------------------------------------------------
function GetXmlParserVersion()
{
	if (!g_sXmlParserProgID) g_sXmlParserProgID = GetXmlParserProgID();

	var reg = /\d+.\d+/g;
	var ar = reg.exec(g_sXmlParserProgID);
	return (ar ? ar[0] : "0.0");
}

//--------------------------------------------------------------------
// Function: LoadXML
//
// Purpose: Loads the specified xml fragment
//
// Parameters:
//	String sXML [in] - Xml fragment
//
// Returns: XMLDOM object or null
//
// Note: Function can throw
//--------------------------------------------------------------------
function LoadXML(sXML)
{
	if (!sXML || "string" != typeof(sXML)) return null;
		
	var oXML = new ActiveXObject(GetXmlParserProgID());
	oXML.async = false;
	oXML.validateOnParse = false;
	oXML.resolveExternals = false;
	oXML.setProperty("SelectionLanguage", "XPath");
	try {oXML.setProperty("NewParser", true);} catch(e){}

	oXML.loadXML(sXML);
	if (0 != oXML.parseError.errorCode)
	{
		var oError = new Object();
		oError.number = oXML.parseError.errorCode;
		oError.description = oXML.parseError.reason;
		throw(oError);
	}
		
	return oXML;
}

//--------------------------------------------------------------------
// Function: LoadXMLFile
//
// Purpose: Loads the specified xml file.
//
// Parameters:
//	String sFile [in] - Xml filename
//
// Returns: XMLDOM object OR null
//
// Note: Function can throw
//--------------------------------------------------------------------
function LoadXMLFile(sFile)
{
	if (!sFile || "string" != typeof(sFile)) return null;
		
	var oXML = new ActiveXObject(GetXmlParserProgID());
	oXML.async = false;
	oXML.validateOnParse = false;
	oXML.resolveExternals = false;
	oXML.setProperty("SelectionLanguage", "XPath");
	try {oXML.setProperty("NewParser", true);} catch(e){}

	oXML.load(sFile);
	if (0 != oXML.parseError.errorCode)
	{
		var oError = new Object();
		oError.number = oXML.parseError.errorCode;
		oError.description = ERR_CANNOT_LOAD_XML_FILE + sFile + "\n" + oXML.parseError.reason;
		throw(oError);
	}
		
	return oXML;
}

//--------------------------------------------------------------------
// Function: GetFlashVersion
//
// Purpose: Gets the highest installed version of Macromedia Flash.
//
// Parameters: None
//
// Returns: Number
//--------------------------------------------------------------------
function GetFlashVersion()
{
	var MAX_FLASH_VERSION = 10;	// Start with version 10 just in case the viewer has a long lifespan
	var MIN_FLASH_VERSION = 1; 
	var oControl = null;
	var sClassName = "";
	var nVersion = 0;
	
	// Step down through possible versions
  	for (var i = MAX_FLASH_VERSION; i >= MIN_FLASH_VERSION; i--)
	{
		// Set up the classname for the version that we're trying to instantiate
		sClassName = "ShockwaveFlash.ShockwaveFlash";

		// The class name for Flash version 1 is "ShockwaveFlash.ShockwaveFlash"
		if (i > MIN_FLASH_VERSION) sClassName += "." + i.toString();

		try
		{
			oControl = new ActiveXObject(sClassName);
			nVersion = i;
			break;
		}
		catch(e)
		{
		}
	}

	oControl = null;

  	return nVersion;
}