//////////////////////////////////////////////////////////////////////////////
//
// Copyright  2002-2003, Microsoft Corporation.  All rights reserved.
//
// File: Helpmenu.js
//
// Description: Implements functionality associated with the viewer's help menu.
//
//////////////////////////////////////////////////////////////////////////////

if (!Array.prototype.pop) Array.prototype.pop = array_pop;	// required under IE 5.01
var g_oHelpWin = null;
var g_oAboutWin = null;
var g_aCustomWin = null;

// These globals are also used within about.htm
var g_nAboutWinWidth = 390;
var g_nAboutWinHeight = 300;

//--------------------------------------------------------------------
// Function: DisplayHelp
//
// Purpose: Displays the viewer help.  If a window already exists, it gives
//	    the window focus.
//
// Parameters:
//	Boolean bFromViewer [in] - Flag that indicates whether called from topmost
//			   	   viewer window.
// Returns: None
//--------------------------------------------------------------------
function DisplayHelp(bFromViewer)
{
	try
	{
		if (!g_oHelpWin || g_oHelpWin.closed)
		{
			var sPath = GetBaseURL() + "viewer/help/Help.htm";

			var xOffset = (screen.width - 640)/2, yOffset = (screen.height - 480)/2;
   			var sWinProps = "toolbar=no,location=no,directories=no,menubar=no,scrollbars=yes,resizable=yes,status=no,height=480,width=640,left=" + xOffset + ",top=" + yOffset;

    			g_oHelpWin = window.open(sPath,"",sWinProps);
			if (g_oHelpWin) window.attachEvent("onunload",HelpWinClose);
		}
		g_oHelpWin.focus();
	}
	catch(e)
	{
	}
}

//--------------------------------------------------------------------
// Function: HelpWinClose
//
// Purpose: Closes the help window.
//
// Parameters: None
//
// Returns: None
//--------------------------------------------------------------------
function HelpWinClose()
{
	try {g_oHelpWin.close();} catch(e) {}
}

//--------------------------------------------------------------------
// Function: DisplayAbout
//
// Purpose: Creates a window that displays information about the viewer.
//
// Parameters: None
//
// Returns: None
//--------------------------------------------------------------------
function DisplayAbout()
{
	try
	{
		var xOffset = (screen.width - g_nAboutWinWidth)/2, yOffset = (screen.height - g_nAboutWinHeight)/2;
   		var sWinProps = "toolbar=no,location=no,directories=no,menubar=no,scrollbars=yes,resizable=no,status=no,height=" + g_nAboutWinHeight + ",width=" + g_nAboutWinWidth + ",left=" + xOffset + ",top=" + yOffset;

		var sURL = GetBaseURL() + "viewer/about.htm";

    		g_oAboutWin = window.open(sURL,"",sWinProps);
		if (g_oAboutWin)
		{
			window.attachEvent("onunload",AboutWinClose);
			g_oAboutWin.focus();
		}
	}
	catch(e)
	{
	}
}

//--------------------------------------------------------------------
// Function: AboutWinClose
//
// Purpose: Closes the About window.
//
// Parameters: None
//
// Returns: None
//--------------------------------------------------------------------
function AboutWinClose()
{
	try {g_oAboutWin.close();} catch(e) {}
}

//--------------------------------------------------------------------
// Function: DisplayCustomItem
//
// Purpose: Creates a window that displays the specified page that
//	    corresponds to a custom help menu item.
//
// Parameters: None
//
// Returns: None
//--------------------------------------------------------------------
function DisplayCustomItem(Href)
{
	try
	{
		// allow only one window per menu item
		if (g_aCustomWin)
		{
			for (var i = 0; i < g_aCustomWin.length; i++)
			{
				if (g_aCustomWin[i] && !g_aCustomWin[i].closed && unescape(g_aCustomWin[i].location.href.toLowerCase()).indexOf(Href.toLowerCase()) != -1)
				{
					g_aCustomWin[i].focus();
					return;
				}
			}
		}

		var xOffset = (screen.width - 640)/2, yOffset = (screen.height - 480)/2;
   		var sWinProps = "toolbar=no,location=no,directories=no,menubar=no,scrollbars=yes,resizable=yes,status=no,height=480,width=640,left=" + xOffset + ",top=" + yOffset;

		if (!g_aCustomWin) g_aCustomWin = new Array;
		
		g_aCustomWin[g_aCustomWin.length] = window.open(Href,"",sWinProps);
		if (g_aCustomWin[g_aCustomWin.length-1])
		{
			window.attachEvent("onunload",CloseAllCustomHelpWindows);
			g_aCustomWin[g_aCustomWin.length-1].attachEvent("onunload",UpdateCustomWinArray);
			g_aCustomWin[g_aCustomWin.length-1].focus();
		}
	}
	catch(e)
	{
	}
}

//--------------------------------------------------------------------
// Function: UpdateCustomWinArray
//
// Purpose:
//	
//
// Parameters: None
//
// Returns: None
//--------------------------------------------------------------------
function UpdateCustomWinArray()
{
	try
	{
		sortCustomWinArray();

		// resize the array if a window has been closed
		for (var i = g_aCustomWin.length-1; i >= 0; i--)
			if (g_aCustomWin[i].closed) g_aCustomWin.pop();
	}
	catch(e)
	{
	}
}

//--------------------------------------------------------------------
// Function: CloseAllCustomHelpWindows
//
// Purpose: Closes all windows associated with help menu items that are
//	    defined within the manifest.
//
// Parameters: None
//
// Returns: None
//--------------------------------------------------------------------
function CloseAllCustomHelpWindows()
{
	try
	{
		for (var i = 0; i < g_aCustomWin.length; i++)
			g_aCustomWin[i].close();
	}
	catch(e)
	{
	}
}

//--------------------------------------------------------------------
// Function: sortCustomWinArray
//
// Purpose:
//	
//
// Parameters: None
//
// Returns: None
//--------------------------------------------------------------------
function sortCustomWinArray()
{
	sortProp = "closed";		// sort on the window's closed property
	g_aCustomWin.sort(sortFunc);
}

//--------------------------------------------------------------------
// Function: sortFunc
//
// Purpose:
//	
//
// Parameters:
//	obj1 [in] - First item to compare
//	obj2 [in] - Second item to compare
//
// Returns: -1, 0 or 1
//--------------------------------------------------------------------
function sortFunc(obj1,obj2)
{
	if (obj1[sortProp] < obj2[sortProp]) return -1;
	else if (obj1[sortProp] > obj2[sortProp]) return 1;
	else return 0;
}