///////////////////////////////////////////////////////////////////////////////////////////////////
//
// Copyright  2002-2003, Microsoft Corporation.  All rights reserved.
//
// File: FindLMSAPI.js
//
// Description: Contains the client-side script that searches the window and framesets hierarchy 
//		to find an implementation of the SCORM API adapter object.
//
///////////////////////////////////////////////////////////////////////////////////////////////////

//--------------------------------------------------------------------
// Function: FindLMSAPI
//
// Purpose: This function retrieves the JScript LMSAPI object.  Starting
//	    with the current window, it checks for the LMSAPI object.
//	    It then traces back through the windows' parents.  If the
//	    LMSAPI object is found, it is returned.  Once the trace back
//	    ends, the algorithm checks the opener window and all its
//	    parents for the LMSAPI object.
//
// Parameters: None
//
// Returns: Object OR null
//--------------------------------------------------------------------
function FindLMSAPI()
{
	var oAPI = null;
	var oWalkOpeners = window;
	var oWalkParents = window;
	
	try
	{
		while (oWalkOpeners)
		{
			while (oWalkParents)
			{
				if ("object" == typeof(oWalkParents.API)) 
				{
					try
					{
						// Call a SCORM API function.  If it doesn't throw,
						// we have found the correct object.
						oWalkParents.API.LMSGetLastError();
						oAPI = oWalkParents.API;
						break;
					}
					catch(e)
					{
					}
				} 
				
				if (oWalkParents == oWalkParents.parent) break;

				oWalkParents = oWalkParents.parent;
			}

			if (oAPI || (oWalkOpeners == oWalkOpeners.opener)) break;

			oWalkOpeners = oWalkOpeners.opener;
			oWalkParents = oWalkOpeners;
		}
	}
	catch(e)
	{
	}

	return oAPI;
}