//////////////////////////////////////////////////////////////////////////////
//
// Copyright  2002-2003, Microsoft Corporation.  All rights reserved.
//
// File: Menu.js
//
// Description: Implements functionality used to display menus.
//
//////////////////////////////////////////////////////////////////////////////

//-------------------------------------------------------------------
// Function: ShowMenu
//
// Purpose: Displays the menu that is associated with the specified
//	    element.
//
// Parameters:
//	Object ev [in] - Menu item parent element
//
// Returns: None
//-------------------------------------------------------------------
function ShowMenu(ev)
{
	try
	{
		var oMenuFrame = document.all.MenuFrame;
		var oStyle = oMenuFrame.style;
		var ocMenu = MenuFrame.cMenu;

		oStyle.display = "inline";
	
		LoadMenuItems(ev);

		var TextRect = ocMenu.getBoundingClientRect();
		var x = TextRect.right - TextRect.left;
		var y = TextRect.bottom - TextRect.top;
	
		var oMenuItems = ocMenu.children;
		var nPaddingOffset = parseInt(ocMenu.style.paddingRight) + parseInt(oMenuItems(0).style.paddingRight);
		oMenuFrame.width = x + nPaddingOffset;
		oMenuFrame.height = y;

		for (var i = 0; i < oMenuItems.length; i++)
		{
			oMenuItems(i).style.posWidth = x;
			oMenuItems(i).tabIndex = 1;
		}

// MV CHANGE - moved position to here in code after all adjustments are made and items are loaded...

		var iLabelWidth	= ev.parentElement.offsetWidth;

		var iMnuWidth	= MenuFrame.cMenu.offsetWidth;
		iLabelWidth	= ev.parentElement.offsetWidth;

		oStyle.posLeft = GetElementPos(ev.parentElement,"Left");
		if ( document.dir.toLowerCase() == "rtl" )	oStyle.posLeft -= ( iMnuWidth - iLabelWidth );
		oStyle.posTop = GetElementPos(ContentFrameTbl,"Top");
// END MV CHANGE

		oStyle.visibility = "visible";

		// Temporary work-around: Search for 'disabled' within the item's HTML; 
		// We//should* be able to test for oMenuItems(0).disabled == false,
		// but IE 5.01 fails when attempting to get the value of the 'disabled' property.
		if (oMenuItems(0).outerHTML.indexOf("disabled") == -1)
			oMenuItems(0).focus();
	}
	catch(e)
	{
	}
}

//-------------------------------------------------------------------
// Function: HideMenu
//
// Purpose: Hides the current menu.
//
// Parameters: None
//
// Returns: None
//-------------------------------------------------------------------
function HideMenu()
{
	try {document.all.MenuFrame.style.visibility = "hidden";} catch(e) {}
}

//-------------------------------------------------------------------
// Function: MoveMenu
//
// Purpose: Moves the current menu relative to the position of its
//	    parent item.
//
// Parameters: None
//
// Returns: None
//-------------------------------------------------------------------
function MoveMenu()
{
	try
	{

		var oMenuFrame = document.all.MenuFrame;
		var oStyle = oMenuFrame.style;
		if (oStyle.visibility == "visible")
		{

// MV CHANGE
			var iMnuWidth	= MenuFrame.cMenu.offsetWidth;
			var iLabelWidth	= document.all(MenuFrame.cMenu.parentID).parentElement.offsetWidth;

			oStyle.posLeft = GetElementPos(document.all(MenuFrame.cMenu.parentID).parentElement,"Left");
			if ( document.dir.toLowerCase() == "rtl" )	oStyle.posLeft -= ( iMnuWidth - iLabelWidth );

// END MV CHANGE
			oStyle.posTop = GetElementPos(ContentFrameTbl,"Top");

		}
	}
	catch(e)
	{
	}
}

//-------------------------------------------------------------------
// Function: LoadMenuItems
//
// Purpose: Loads the menu items that are to be displayed.
//
// Parameters:
//	Object ev [in] - 
//
// Returns: None
//
// Note: Function can throw
//-------------------------------------------------------------------
function LoadMenuItems(ev)
{
	var oMenu = MenuFrame.cMenu;

	// Clear existing menu items
	var oMenuItems = oMenu.children;
	while (oMenuItems.length)
		oMenuItems(0).removeNode(true);

	oMenu.style.width = 0;
	oMenu.parentID = ev.id;

	var bDisable = (API) ? API.LRNIsViewerOffline() : false;
	
	// Add items associated with the respective menu
	switch (ev.innerText)
	{
		case LBL_BOOKMARK_MENU:
			AddMenuItem(LBL_BOOKMARKMENU_ADD,"AddBookmark()");
			AddMenuItem(LBL_BOOKMARKMENU_MANAGE,"ManageBookmarks()");
			break;
		case LBL_NOTEBOOK_MENU:
			break;
		case LBL_HELP_MENU:
			AddMenuItem(LBL_HELPMENU_VIEWERHELP,"DisplayHelp()");
			
			// Add custom help menu items between viewer help and about
			var aList = API.LRNGetCustomHelpMenuItemList();
			if (aList && aList.length > 0)
				for (var i = 0; i < aList.length; i++)
					AddMenuItem(aList[i].name,"DisplayCustomItem(&quot;"+ aList[i].href +"&quot;)");

			AddMenuItem(LBL_HELPMENU_ABOUT,"DisplayAbout()");
			break;
	}
}

//-------------------------------------------------------------------
// Function: AddMenuItem
//
// Purpose: Appends a new item to the menu.
//
// Parameters:
//	String sText	 [in] - 
//	String sAction	 [in] - 
//	Boolean bDisable [in] - 
//
// Returns: None
//
// Note: Function can throw
//-------------------------------------------------------------------
function AddMenuItem(sText,sAction,bDisable)
{
	var sID = "mnuItem" + MenuFrame.cMenu.children.length;
	var sElement = "<div id='" + sID + "' name='" + sID + "' style='padding-top:2px;padding-left:4px;padding-right:4px;padding-bottom:1px;margin:0px;' class='cmenuitem' action='" + sAction + "' tabindex='-1' ";

	if (bDisable)
		sElement += "disabled />";
	else
		sElement += " />";

	var oElement = MenuFrame.document.createElement(sElement);

//MV CHANGE needed to apply direction directly :)

	oElement.dir = document.dir;
	oElement.innerHTML = sText;
	
	MenuFrame.cMenu.appendChild(oElement);
}