//////////////////////////////////////////////////////////////////////////////
//
// Copyright  2002-2003, Microsoft Corporation.  All rights reserved.
//
// File: Viewer.js
//
// Description: Functionality associated with viewer.htm.  These functions
//		are in a separate file so loading can be deferred for
//		improved performance.
//
//////////////////////////////////////////////////////////////////////////////

//--------------------------------------------------------------------
// Function: document.ondragstart
//
// Purpose:
//
//
//
// Parameters: None
//
// Returns: None
//--------------------------------------------------------------------
function document.ondragstart()
{
	// don't allow elements to be dragged onto the desktop
	CancelEvent();
}

//--------------------------------------------------------------------
// Function: document.oncontextmenu
//
// Purpose:
//
//
//
// Parameters: None
//
// Returns: None
//--------------------------------------------------------------------
function document.oncontextmenu()
{
	if (event.srcElement.id != "idsearchinput")	// only display default context menu for search
	{
 		CancelEvent();
	}
}

//--------------------------------------------------------------------
// Function: document.onkeypress
//
// Purpose:
//
//
//
// Parameters: None
//
// Returns: None
//--------------------------------------------------------------------
function document.onkeypress()
{

//MV CHANGE - adding bannerlink code back in - see diff

	switch (event.srcElement.id)
	{
		case "BannerLinkBtn":
		case "BannerLinkLabel":
		case "TocBtn":
		case "TocMenuLabel":
		case "BookmarkMenuLabel":
		case "NotebookMenuLabel":
		case "HelpMenuLabel":
		case "PreviousLink":
		case "PreviousBtn":
		case "NextLink":
		case "NextBtn":
		{
			if (event.keyCode == ASCII_KEYCODE_ENTER)
			{
				document.onclick();
				event.cancelBubble = true;
				event.returnValue = false;
				break;
			}
		}
		case "idsearchinput":
			if (event.keyCode == ASCII_KEYCODE_ENTER)
				BasicSearchGoBtn.click();
	}

	HandleKeys(event);
}

//--------------------------------------------------------------------
// Function: document.onkeyup
//
// Purpose:
//
//
//
// Parameters: None
//
// Returns: None
//--------------------------------------------------------------------
function document.onkeyup()	// ALT modifier cannot be trapped using document.onkeypress() or document.onkeydown()
{
	HandleKeys(event);
}

//--------------------------------------------------------------------
// Function: document.onclick
//
// Purpose:
//
//
//
// Parameters: None
//
// Returns: None
//--------------------------------------------------------------------
function document.onclick()
{

//MV CHANGE - adding bannerlink code back in - see diff

	try
	{
		if (g_bModal)
		{
			CancelEvent();
			return;
		}

		switch (event.srcElement.id)
		{
			case "BannerLinkLabel":
			case "BannerLinkBtn":
			case "imgBannerLinkBtn":
				window.location.href = URI_BANNER_LINK;
				break;
			case "TocMenuLabel":
			case "TocBtn":
			case "imgTocBtn":
				ToggleToc();
				break;
			case "PreviousLink":
			case "PreviousBtn": 
			case "imgPreviousBtn":
				if (!PreviousBtn.disabled) API.LRNDoPrevious();
				break;
			case "NextLink":
			case "NextBtn":
			case "imgNextBtn":
				if (!NextBtn.disabled) API.LRNDoNext();
				break;
			case "BookmarkMenuLabel":
			case "NotebookMenuLabel":
			case "HelpMenuLabel":
				ShowMenu(event.srcElement);
				return;
		}

		if (event.srcElement.tagName != "U") HideMenu();
	}
	catch(e)
	{
	}
}

//--------------------------------------------------------------------
// Function: ToggleToc
//
// Purpose:
//
//
//
// Parameters: None
//
// Returns:
//--------------------------------------------------------------------
function ToggleToc()
{
	var oTocFrameStyle = g_oTocFrame.style;

	if (oTocFrameStyle.display == "" || oTocFrameStyle.display == "inline")
	{
		oTocFrameStyle.display = "none";
		divSep.style.display = "none";
		imgTocBtn.alt = LBL_TOC_TOOLTIP_SHOW;
		TocMenuLabel.title = LBL_TOC_TOOLTIP_SHOW;
	}
	else
	{
		oTocFrameStyle.display = "inline";
		divSep.style.display = "inline";
		imgTocBtn.alt = LBL_TOC_TOOLTIP_HIDE;
		TocMenuLabel.title = LBL_TOC_TOOLTIP_HIDE;

		TocFrame.document.body.ScrollToNode();
	}

	PositionFrames();
}

//--------------------------------------------------------------------
// Function: divSep_onmouseup
//
// Purpose:
//
//
//
// Parameters: None
//
// Returns: None
//--------------------------------------------------------------------
function divSep_onmouseup()
{
	divSep.releaseCapture();
}

//--------------------------------------------------------------------
// Function: divSep_onmousedown
//
// Purpose:
//
//
//
// Parameters: None
//
// Returns: None
//--------------------------------------------------------------------
function divSep_onmousedown()
{
	divSep.setCapture();
}

//--------------------------------------------------------------------
// Function: divSep_onmousemove
//
// Purpose:
//
//
//
// Parameters: None
//
// Returns: None
//--------------------------------------------------------------------
function divSep_onmousemove() 
{
	if (event.button == MOUSE_BUTTON_LEFT)
	{
		if (document.dir == "rtl")
			divSepMove(document.body.clientWidth - event.clientX);
		else
			divSepMove(event.clientX);
	}
}

//--------------------------------------------------------------------
// Function: divSep_onkeypress
//
// Purpose:
//
//
//
// Parameters: None
//
// Returns: None
//--------------------------------------------------------------------
function divSep_onkeypress() 
{
	var evX = g_oTocFrame.style.posWidth;
	var nDelta = (document.dir == "rtl") ? -10 : 10;
	
	switch (event.keyCode)
	{
		case ASCII_KEYCODE_ARROW_RIGHT:
			evX += nDelta;
			break;
		case ASCII_KEYCODE_ARROW_LEFT:
			evX -= nDelta;
			break;
		default:
			return;
	}

	divSepMove(evX);
	window.scrollBy(-evX,0);
}

//--------------------------------------------------------------------
// Function: divSepMove
//
// Purpose:
//
//
//
// Parameters:
//	evX [in] - 
//
// Returns: None
//--------------------------------------------------------------------
function divSepMove(evX)
{
	var oTocFrameStyle = g_oTocFrame.style;
	var nDivSepWidth = divSep.clientWidth;
	var nDocBodyWidth = document.body.clientWidth;
	
	oTocFrameStyle.posWidth = evX;

	// Don't allow the divider to move beyond the client edge
	if (oTocFrameStyle.posWidth >= nDocBodyWidth - nDivSepWidth)
		oTocFrameStyle.posWidth = nDocBodyWidth - nDivSepWidth;
		
	ContentAreaTbl.posWidth = nDocBodyWidth - (g_oTocFrame.clientWidth + nDivSepWidth);

	SaveOrigTocWidth();
}

//--------------------------------------------------------------------
// Function: ForceTocRedraw
//
// Purpose: Causes the TOC to redraw (fixes bug #4347).
//
// Parameters: None
//
// Returns: None
//--------------------------------------------------------------------
function ForceTocRedraw()
{
	var oTocFrameStyle = g_oTocFrame.style;
	var nWidth = oTocFrameStyle.pixelWidth;
	oTocFrameStyle.pixelWidth = nWidth + 10;
	oTocFrameStyle.pixelWidth = nWidth;
}

//--------------------------------------------------------------------
// Function: ChangeButtonImage
//
// Purpose:
//
//
//
// Parameters: None
//
// Returns: None
//--------------------------------------------------------------------
function ChangeButtonImage()
{
	var nState = -1;
	switch (event.type)
	{
		case "mouseover":
			nState = BUTTON_STATE_RO;
			break;
		case "mouseout":
			nState = BUTTON_STATE_NORMAL;
			break;
		case "mousedown":
			if (event.button == MOUSE_BUTTON_LEFT)
			{
				nState = BUTTON_STATE_DOWN;
				break;
			}
		case "mouseup":
			if (event.button == MOUSE_BUTTON_LEFT)
			{
				nState = BUTTON_STATE_RO;
				break;
			}
		default:
			return;
	}
	
	var oSrc = event.srcElement;
	var sID = (oSrc.tagName != "U") ? oSrc.id : oSrc.parentElement.id;
	
	switch (sID)
	{
		case "imgBannerLinkBtn":
		case "BannerLinkLabel":
			imgBannerLinkBtn.src = g_aImgBannerLinkBtn[nState].src;
			BannerLinkLabel.className = (nState == BUTTON_STATE_NORMAL) ? "BannerLinkLabel" : "BannerLinkLabelRO";
			if (BannerLinkLabel.children.length) BannerLinkLabel.children(0).className = (nState == BUTTON_STATE_NORMAL) ? "BannerLinkLabel" : "BannerLinkLabelRO";
			break;
		case "imgTocBtn":
		case "TocMenuLabel":
			if (g_oTocFrame.style.display == "" || g_oTocFrame.style.display == "inline")
				if (event.type != "mouseup")
					imgTocBtn.src = g_aImgTocUpBtn[nState].src;
				else
					imgTocBtn.src = g_aImgTocDownBtn[nState].src;
			else
				if (event.type != "mouseup")
					imgTocBtn.src = g_aImgTocDownBtn[nState].src;
				else
					imgTocBtn.src = g_aImgTocUpBtn[nState].src;

			TocMenuLabel.className = (nState == BUTTON_STATE_NORMAL) ? "TocMenuLabel" : "TocMenuLabelRO";
			if (TocMenuLabel.children.length) TocMenuLabel.children(0).className = (nState == BUTTON_STATE_NORMAL) ? "TocMenuLabel" : "TocMenuLabelRO";
			break;
		case "imgPreviousBtn":
		case "PreviousLink":
			if (!PreviousBtn.disabled) 
			{
				imgPreviousBtn.src = g_aImgPreviousBtn[nState].src;
				PreviousLink.className = (nState == BUTTON_STATE_NORMAL) ? "NavLabelText" : "NavLabelTextRO";
				if (PreviousLink.children.length) PreviousLink.children(0).className = (nState == BUTTON_STATE_NORMAL) ? "NavLabelText" : "NavLabelTextRO";
			}
			break;
		case "imgNextBtn":
		case "NextLink":
			if (!NextBtn.disabled)
			{
				imgNextBtn.src = g_aImgNextBtn[nState].src;
				NextLink.className = (nState == BUTTON_STATE_NORMAL) ? "NavLabelText" : "NavLabelTextRO";
				if (NextLink.children.length) NextLink.children(0).className = (nState == BUTTON_STATE_NORMAL) ? "NavLabelText" : "NavLabelTextRO";
			}
			break;
		default:
			return;
	}
}

//--------------------------------------------------------------------
// Function: onContentFrameKeypress
//
// Purpose:
//
//
//
// Parameters: None
//
// Returns: None
//--------------------------------------------------------------------
function onContentFrameKeypress()
{
	HandleKeys(ContentFrame.event);
}

//--------------------------------------------------------------------
// Function: HandleKeys
//
// Purpose:
//
//
//
// Parameters: 
//
// Returns: None
//--------------------------------------------------------------------
function HandleKeys(oEvent)
{
	try
	{
		if (oEvent.altKey)
		{
			HideMenu();

			switch (String.fromCharCode(oEvent.keyCode))
			{
				case LBL_PREVIOUS_TOPIC_ACCESSKEY:
					if (!PreviousBtn.disabled) API.LRNDoPrevious();
					break;
				case LBL_NEXT_TOPIC_ACCESSKEY:
					if (!NextBtn.disabled) API.LRNDoNext();
					break;
				case LBL_TOC_MENU_ACCESSKEY:
					ToggleToc();
					if (g_oTocFrame.style.display == "inline")
					{
						if (TocMenuLabel.className == "TocMenuLabel")
							imgTocBtn.src = g_aImgTocUpBtn[BUTTON_STATE_NORMAL].src;
						else
							imgTocBtn.src = g_aImgTocUpBtn[BUTTON_STATE_RO].src;
					}
					else
					{
						if (TocMenuLabel.className == "TocMenuLabel")
							imgTocBtn.src = g_aImgTocDownBtn[BUTTON_STATE_NORMAL].src;
						else
							imgTocBtn.src = g_aImgTocDownBtn[BUTTON_STATE_RO].src;
					}
					break;
				case LBL_BOOKMARK_MENU_ACCESSKEY:
					ShowMenu(BookmarkMenuLabel);
					break;
				case LBL_NOTEBOOK_MENU_ACCESSKEY:
					ShowMenu(NotebookMenuLabel);
					break;
				case LBL_HELP_MENU_ACCESSKEY:
					ShowMenu(HelpMenuLabel);
					break;
				case LBL_ADVANCED_SEARCH_ACCESSKEY:
					AdvSearchLink.click();
					break;
				case LBL_BANNER_LINK_ACCESSKEY:
					BannerLinkLabel.click();
			}
		}
		
		if (oEvent.ctrlKey)
		{
			switch (oEvent.keyCode)
			{
				case ASCII_KEYCODE_CTRL_J:
					ContentFrame.focus();
					break;
				case ASCII_KEYCODE_CTRL_Q:
					DisplayHelp(1);
					break;
				case ASCII_KEYCODE_CTRL_1:
					TocBtn.focus();
					break;
				case ASCII_KEYCODE_CTRL_2:
					TocFrame.focus();
					break;
				case ASCII_KEYCODE_CTRL_3:
					TopicWheelFrame.focus();
					break;
				case ASCII_KEYCODE_CTRL_4:
					NotesFrame.focus();
					break;
				case ASCII_KEYCODE_CTRL_5:
					if (!PreviousBtn.disabled)
						PreviousBtn.focus();
					else
						NextBtn.focus();
					break;
			}
		}
	}
	catch(e)
	{
	}
}

//--------------------------------------------------------------------
// Function: CancelEvent
//
// Purpose: Cancels the current event.
//
// Parameters: None
//
// Returns: None
//--------------------------------------------------------------------
function CancelEvent()
{
	event.cancelBubble = true;
	event.returnValue = false;
}